
/*  -*- MaTX -*-
 *
 *  【名前】
 *      linspace() - 線形等間隔ベクトル
 *
 *  【形式】
 *      y = linspace(x1, x2, n, ...)
 *         Array y;
 *         Real x1, x2;
 *         ...
 *         Integer n = 100;
 *
 *  【機能説明】
 *      linspace(x1,x2) は，x1 と x2 を等間隔で 100 分割した 100 個の
 *      値からなる行ベクトルを返す。
 *      linspace(x1,x2,N) は，x1 と x2 を等間隔で N 分割した N 個の
 *      値からなる行ベクトルを返す。
 *
 *  【関連項目】
 *      logspace
 */

Func Array linspace(x1, x2, n, ...)
	Real x1, x2;
	Integer n;
{
	Array y;
	
	error(nargchk(2, 3, nargs, "linspace"));

	if (nargs == 2) {
		n = 100;
	} 

	y = [x1 .+ [0:n-2]*(x2-x1)/(n-1), x2];
	return y;
}
