
/*  -*- MaTX -*-
 *
 *  【名前】
 *      conjtrans() - 複素共役転置
 *
 *  【形式】
 *      y = conjtrans(x)
 *         (Integer|Real|Complex|Polynomial|Rational) y;
 *         (Integer|Real|Complex|Polynomial|Rational) x;
 *
 *      Y = conjtrans(X)
 *         (Matrix|Array) Y;
 *         (Matrix|Array) X;
 *
 *  【機能説明】
 *      (整数|実数) x について，conjtrans(x)は x 自身になる。複素数 x 
 *      について，conjtrans(x) は，x の共役複素数を求める。(多項式|
 *      有理多項式) x について，conjtrans(x) は x の各係数を共役複素
 *      数にした値を求める。
 *
 *	    conjtrans(X)は，(行列|配列) X の複素共役転置 X# を求める。
 *
 *  【例題】
 *      >> y = conjtrans(3.14)
 *      y = 3.14
 *      >> y = conjtrans((3.14, 2.6))
 *      y = (3.14, -2.6)
 *      >> s = Polynomial("s");
 *      >> y = conjtrans((1,3)*s + (2,4))
 *      y = (1,-3) s + (2,-4)
 *      >> y = conjtrans([(1,2), (3,4)])
 *      === [y] : (  2,  1) ===
 *             [ (  1)-Real      (  1)-Imag ]
 *      (  1)  1.00000000E+00 -2.00000000E+00
 *      (  2)  3.00000000E+00 -4.00000000E+00
 *
 *  【関連項目】
 *      trans(), conj()
 */
