
/*  -*- MaTX -*-
 *
 *  【名前】
 *      ifft_row() - 行毎の逆高速フーリエ変換
 *
 *  【形式】
 *      Y = ifft_row(X)
 *         (CoMatrix|CoArray) Y;
 *         (Matrix|Array) X;
 *
 *      Y = ifft_row(X,k)
 *         (CoMatrix|CoArray) Y;
 *         (Matrix|Array) X;
 *         Integer k;
 *
 *  【機能説明】
 *      ifft_row(X)は，2 のべき乗の長さのベクトル X について，基底が 
 *      2 の逆高速フーリエ変換を計算する。ifft_row(X,k) は k 点の逆高
 *      速フーリエ変換をする。X の長さが k より短いとき，ゼロが後ろに
 *      付け加えられ，X の長さが k より長いとき，k 番目以降が切り捨て
 *      られる。
 *
 *      X が行列のとき，行毎に逆高速フーリエ変換を求める。
 *
 *  【例題】
 *      フーリエ変換した信号を ifft_row() で逆フーリエ変換すると，元の
 *      信号に戻る。以下の例で，x2 は丸め誤差の範囲で x と一致する。
 *
 *      x = [[5, 4, 8, -8, 2, 0, 0, 0][6, 5, 9, -9, 3, 0, 0, 0]];
 *      X = fft_row(x);
 *      x2 = ifft_row(X);
 *
 *  【関連項目】
 *      ifft(), ifft_col(), fft_row()
 */
