
/*  -*- MaTX -*-
 *
 *  【名前】
 *      integral() - 積分(不定積分)
 *
 *  【形式】
 *      y = integral(x)
 *         (Integer|Real|Complex|Polynomial) y;
 *         (Integer|Real|Complex|Polynomial) x;
 *
 *      y = integral(x,k)
 *         (Integer|Real|Complex|Polynomial) y;
 *         (Integer|Real|Complex|Polynomial) x;
 *         Integer k;
 *
 *      Y = integral(X)
 *         (Matrix|Array) Y;
 *         (Matrix|Array) X;
 *
 *      Y = integral(X,k)
 *         (Matrix|Array) Y;
 *         (Matrix|Array) X;
 *         Integer k;
 *
 *  【機能説明】
 *      (整数|実数|複素数|多項式) x について，integral(x)は x の不定積分
 *      を求める。integral(x,k) は k 階の不定積分を求める。
 *
 *	    X が(行列|配列)のとき，X の各成分に integral(X(i,j)) を作用した
 *      結果からなる(行列|配列)を求める。Y の大きさは X の大きさと同じになる。
 *      integral(X,k) は k 階の不定積分を求める。
 *
 *  【例題】
 *      >> y = integral(3.14)
 *      y = 3.14 s
 *      >> y = integral((3.14, 2.6))
 *      y = (3.14, 2.6) s
 *      >> s = Polynomial("s");
 *      >> y = integral((1,3)*s + (2,4))
 *      y = (0.5,1.5) s^2 + (2,4) s
 *      >> Y = integral([2*s+1, 2])
 *      === [Y] : (  1,  2) ===
 *           [          (  1)           ]  [          (  2)           ]
 *      (  1)          s^2 + s                         2 s            
 *      >> Y = integral([2*s+1, 2], 2)
 *      === [Y] : (  1,  2) ===
 *           [          (  1)           ]  [          (  2)           ]
 *      (  1)   0.333333 s^3 + 0.5 s^2                 s^2            
 *
 *  【関連項目】
 *      derivative()
 */
