
/*  -*- MaTX -*-
 *
 *  【名前】
 *      load - (MM-ファイル|SO-ファイル)の読み込み
 *
 *  【形式】
 *      load;
 *
 *      load (mm|so)-file1,(mm|so)-file2, ..., (mm|so)-filen;
 *          String (mm|so)-file1, (mm|so)-file2, ..., (mm|so)-filen;
 *
 *  【機能説明】
 *      単体の load は，現在のディレクトリにあるファイル MaTX.mm を
 *      読み込む。
 *
 *      load は，MM-ファイルあるいはSO-ファイル(共有ライブラリファイル)
 *      を読み込むことができる。
 *
 *      load file は，ファイル file を読み込む。ファイル名をカンマで
 *      区切って，複数のファイルを同時に指定できる。拡張子を省略する
 *      と，MM-ファイルと見なされる。
 *      
 *      MM-ファイルは，インタプリタのコマンドラインでのみ読み込むこと
 *      ができる。SO-ファイルは、関数内部からでも読み込める。
 *
 *      SO-ファイル afo.so を読み込むと、共有ライブラリファイル中で
 *      定義されている(存在しなければならい)関数 func_afo() がインタ
 *      プリタに自動的に登録される。登録された関数は，組み込み関数と
 *      同様に使用できる。
 *
 *      ライブラリ中で定義されている外部シンボルは，後でロードされる
 *      ライブラリ中のシンボルと競合することはない。
 *
 *      ファイルは，
 *      o 現在のディレクトリ
 *      o 環境変数 MATXINPUTS に定義されたディレクトリ以下の全ての
 *        ディレクトリ(コロンで区切って複数のディレクトリを指定できる。
 *        Windowsでは，セミコロンで区切る。)
 *      o 環境変数 MATXDIR で定義されるディレクトリ内の inputs
 *        ディレクトリ以下の全てのディレクトリ
 *      o デフォルトMM-ファイルディレクトリ以下の全てのディレクトリ
 *        (コンパイル時に決定される)
 *      の順番で探索される。環境変数  LANG に ja，japanese，ja_JP*
 *      (ja_JP で始まる任意の文字列)が設定されていて，各ディレクトリ
 *      に ja というディレクトリが存在すれば，そこが先に検索される。
 *
 *      読み込むファイルを次のように絶対パスで指定できる。
 *
 *        load "/usr/local/tmp/file.mm";
 *        load "/usr/local/tmp/file.so";
 *
 *      Windowsの絶対パスの区切り文字はスラッシュ / と逆スラッシュ \ の
 *      どちらでもよい。
 *
 *        load "c:/tmp/file.mm";
 *
 *      ただし，文字列中の \t や \n などは特殊文字として解釈されるので，
 *
 *        load "c:\\tmp\\file.mm";
 *
 *      のように逆スラッシュ \ を重ねる必要がある。
 *  【例題】
 *      >> load "afo.mm";
 *      >> load "foo.so";
 *
 *  【関連項目】
 *      save, install
 */
