
/*  -*- MaTX -*-
 *
 *  【名前】
 *      maximum_row() - 行毎の最大値とその指数
 *
 *  【形式】
 *         X が行列の場合
 *
 *      {Y,idx} = maximum_row(X)
 *         (Matrix|Array|Index) Y;
 *         Index idx;
 *         Index X;
 *
 *  【機能説明】
 *      X が(行列|配列|指数)のとき，{Y,idx} = maximum_row(X) は行毎に成分
 *      の最大値をを求め，列ベクトル Y で返す。また，最大値の成分の番号か
 *      らなる指数 idx を返す。
 *
 *      X が縦ベクトルまたは横ベクトルのとき，maximum_row(X) は，ベクトル
 *      の成分の最大値とその成分の番号を返す。
 *
 *  【例題】
 *      >> {Y, idx} = maximum_row([[1.2, -2.3][3.1, 0]]);
 *      >> print Y,idx;
 *      === [Y] : (  2,  1) ===
 *                 (  1)     
 *      (  1)  1.20000000E+00
 *      (  2)  3.10000000E+00
 *      === [idx] : (  1,  2) ===
 *                 (  1)           (  2)     
 *      (  1)  1.00000000E+00  1.00000000E+00
 *      >> {Y, idx} = maximum_row([(1,2), (3,4)]);
 *      >> print Y, idx;
 *      === [Y] : (  1,  1) ===
 *             [ (  1)-Real      (  1)-Imag ]
 *      (  1)  3.00000000E+00  4.00000000E+00
 *      === [idx] : (  1,  1) ===
 *                 (  1)     
 *      (  1)  2.00000000E+00
 *
 *  【関連項目】
 *      max(), maximum_col(), minimum_row(), minimum()
 */
