
/*  -*- MaTX -*-
 *
 *  【名前】
 *      minimum_row() - 行毎の最小値とその指数
 *
 *  【形式】
 *         X が行列の場合
 *
 *      {Y,idx} = minimum_row(X)
 *         (Matrix|Array|Index) Y;
 *         Index idx;
 *         Index X;
 *
 *  【機能説明】
 *      X が(行列|配列|指数)のとき，{Y,idx} = minimum_row(X) は行毎に成分
 *      の最小値をを求め，列ベクトル Y で返す。また，最小値の成分の番号か
 *      らなる指数 idx を返す。
 *
 *      X が縦ベクトルまたは横ベクトルのとき，minimum_row(X) は，ベクトル
 *      の成分の最小値とその成分の番号を返す。
 *
 *  【例題】
 *      >> {Y,idx} = minimum_row([[1.2, -2.3][3.1, 0]]);
 *      >> print Y, idx;
 *      === [Y] : (  2,  1) ===
 *                 (  1)     
 *      (  1) -2.30000000E+00
 *      (  2)  0.00000000E+00
 *      === [idx] : (  1,  2) ===
 *                 (  1)           (  2)     
 *      (  1)  2.00000000E+00  2.00000000E+00
 *      >> {Y, idx} = minimum_row([(1,2), (3,4)]);
 *      >> print Y, idx;
 *      === [Y] : (  1,  1) ===
 *             [ (  1)-Real      (  1)-Imag ]
 *      (  1)  1.00000000E+00  2.00000000E+00
 *      === [idx] : (  1,  1) ===
 *                 (  1)     
 *      (  1)  1.00000000E+00
 *
 *  【関連項目】
 *      max(), minimum_row(), minimum_col(), minimum()
 */
